# Lucidchart Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/lucidchart-integration#overview)
  * [Scope](https://help.sap.com/docs/leanix/ea/lucidchart-integration#scope)
  * [Limitations](https://help.sap.com/docs/leanix/ea/lucidchart-integration#limitations)
  * [Setting Up Lucidchart Integration in SAP LeanIX](https://help.sap.com/docs/leanix/ea/lucidchart-integration#setting-up-lucidchart-integration-in-sap-leanix)
  * [Creating and Importing Diagrams from Lucidchart](https://help.sap.com/docs/leanix/ea/lucidchart-integration#creating-and-importing-diagrams-from-lucidchart)
  * [Exporting Diagrams From SAP LeanIX to Lucidchart](https://help.sap.com/docs/leanix/ea/lucidchart-integration#exporting-diagrams-from-sap-leanix-to-lucidchart)
  * [Exporting Diagrams From Lucidchart](https://help.sap.com/docs/leanix/ea/lucidchart-integration#exporting-diagrams-from-lucidchart)


Seamlessly link SAP LeanIX to Lucidchart to extended visual modeling.
